# Changelog

## 1.4.0

- Display niet version by using the flag `-v/--version`
- Allow user to hide the default message when the element was not found

## 1.3.0

- Read input from stdin or from file
- Fix CVE-2017-2809

## 1.2.0

- Add possibility to begin search string by a point eg: .project
- Improve multiples output functionnality
- make adequation between examples in doc and functionnal tests
- Add yaml and json output format
- remove python 3.3 support

## 1.1.0

- Feat. Add capacity to choose between quotes or not
- fix pep8 and check pep8 on travis
- [feat] Add capability to get the whole file using "." as object filter
- Minor cosmetics changes
- doc explain how to update niet

## 1.0.0

- deploy to test.pypi.org on devel
- add some classifiers and change author email
- add badges and improve documentation
- introduce pipenv and pipfile
- add gitignore rules
- introduce tests
- how to contribute to niet
- Introduce code of conduct
- License MIT
- remove changelog from pypi description

## 0.2.2

- fix bad behavior that still to occur on not found

## 0.2.1

- fix bad behavior on element not found
- fix documentation examples

## 0.2.0

- remove tick from list results
- using readme at markdown format on pypi

## 0.1.0

- First commit
